@@ -99,12 +99,7 @@ public class BitbucketPersonalAccessTokenFetcher implements PersonalAccessTokenF
               new PersonalAccessTokenParams(
                   scmServerUrl, tokenName, tokenId, oAuthToken.getToken(), null));
       if (valid.isEmpty()) {
-        throw new ScmCommunicationException(
-            "Unable to verify if current token is a valid Bitbucket token.  Token's scm-url needs to be '"
-                + BitbucketApiClient.BITBUCKET_SERVER
-                + "' and was '"
-                + scmServerUrl
-                + "'");
+        throw buildScmUnauthorizedException(cheSubject);
       } else if (!valid.get().first) {
         throw new ScmCommunicationException(
             "Current token doesn't have the necessary privileges. Please make sure Che app scopes are correct and containing at least: "
@@ -120,14 +115,7 @@ public class BitbucketPersonalAccessTokenFetcher implements PersonalAccessTokenF
           tokenId,
           oAuthToken.getToken());
     } catch (UnauthorizedException e) {
-      throw new ScmUnauthorizedException(
-          cheSubject.getUserName()
-              + " is not authorized in "
-              + OAUTH_PROVIDER_NAME
-              + " OAuth provider.",
-          OAUTH_PROVIDER_NAME,
-          "2.0",
-          getLocalAuthenticateUrl());
+      throw buildScmUnauthorizedException(cheSubject);
     } catch (NotFoundException nfe) {
       throw new UnknownScmProviderException(nfe.getMessage(), scmServerUrl);
     } catch (ServerException | ForbiddenException | BadRequestException | ConflictException e) {
@@ -136,6 +124,17 @@ public class BitbucketPersonalAccessTokenFetcher implements PersonalAccessTokenF
     }
   }
 
+  private ScmUnauthorizedException buildScmUnauthorizedException(Subject cheSubject) {
+    return new ScmUnauthorizedException(
+        cheSubject.getUserName()
+            + " is not authorized in "
+            + OAUTH_PROVIDER_NAME
+            + " OAuth provider.",
+        OAUTH_PROVIDER_NAME,
+        "2.0",
+        getLocalAuthenticateUrl());
+  }
+
   @Override
   public Optional<Boolean> isValid(PersonalAccessToken personalAccessToken) {
     if (!bitbucketApiClient.isConnected(personalAccessToken.getScmProviderUrl())) {
