@@ -61,6 +61,11 @@ public class DefaultFactoryUrl implements RemoteFactoryUrl {
     return URI.create(devfileFileLocation).getHost();
   }
 
+  @Override
+  public String getProviderUrl() {
+    return getHostName();
+  }
+
   @Override
   public String getBranch() {
     return null;
